==> igniteui-webcomponents-layouts-4.8.1.tgz: package/esm2015/lib/igc-tool-action-radio-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionRadio } from "./ToolActionRadio";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionRadioComponent = /*@__PURE__*/ (() => {
    class IgcToolActionRadioComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionRadio();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent == null) {
                let names = getAllPropertyNames(IgcToolActionRadioComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = names;
            }
            return IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent;
        }
        static register() {
            if (!IgcToolActionRadioComponent._isElementRegistered) {
                IgcToolActionRadioComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionRadioComponent.htmlTagName, IgcToolActionRadioComponent);
            }
        }
        /**
         * Gets or sets the channel this radio button belongs to.
        */
        get channel() {
            return this.i.gg;
        }
        set channel(v) {
            this.i.gg = v;
        }
        /**
         * Gets or sets if the tool action is checked.
        */
        get isChecked() {
            return this.i.f9;
        }
        set isChecked(v) {
            this.i.f9 = ensureBool(v);
            this._a("isChecked", this.i.f9);
        }
        /**
         * Gets or sets if the checked state of the radio is handled manually by the user. The radio
         * well not become selected when clicked if this property is true.
        */
        get isManual() {
            return this.i.ga;
        }
        set isManual(v) {
            this.i.ga = ensureBool(v);
            this._a("isManual", this.i.ga);
        }
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get uncheckedBackgroundColor() {
            return brushToString(this.i.g4);
        }
        set uncheckedBackgroundColor(v) {
            this.i.g4 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.g4));
        }
        /**
         * Gets the actual background color of the radio when in the unchecked state.
        */
        get actualUncheckedBackgroundColor() {
            return brushToString(this.i.g0);
        }
        set actualUncheckedBackgroundColor(v) {
            this.i.g0 = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.g0));
        }
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get checkedBackgroundColor() {
            return brushToString(this.i.g2);
        }
        set checkedBackgroundColor(v) {
            this.i.g2 = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.g2));
        }
        /**
         * Gets the actual background color of the radio when in the checked state.
        */
        get actualCheckedBackgroundColor() {
            return brushToString(this.i.gy);
        }
        set actualCheckedBackgroundColor(v) {
            this.i.gy = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.gy));
        }
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get uncheckedBorderColor() {
            return brushToString(this.i.g5);
        }
        set uncheckedBorderColor(v) {
            this.i.g5 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.g5));
        }
        /**
         * Gets the actual border color of the radio when in the unchecked state.
        */
        get actualUncheckedBorderColor() {
            return brushToString(this.i.g1);
        }
        set actualUncheckedBorderColor(v) {
            this.i.g1 = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.g1));
        }
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get checkedBorderColor() {
            return brushToString(this.i.g3);
        }
        set checkedBorderColor(v) {
            this.i.g3 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.g3));
        }
        /**
         * Gets the actual border color of the radio when in the checked state.
        */
        get actualCheckedBorderColor() {
            return brushToString(this.i.gz);
        }
        set actualCheckedBorderColor(v) {
            this.i.gz = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.gz));
        }
        fromInfo(info) {
            this.i.ej(info);
        }
    }
    IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = null;
    IgcToolActionRadioComponent.htmlTagName = "igc-tool-action-radio";
    IgcToolActionRadioComponent._isElementRegistered = false;
    return IgcToolActionRadioComponent;
})();

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm2015/lib/igc-tool-action-radio-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionRadio } from "./ToolActionRadio";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionRadioComponent = /*@__PURE__*/ (() => {
    class IgcToolActionRadioComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionRadio();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent == null) {
                let names = getAllPropertyNames(IgcToolActionRadioComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = names;
            }
            return IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent;
        }
        static register() {
            if (!IgcToolActionRadioComponent._isElementRegistered) {
                IgcToolActionRadioComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionRadioComponent.htmlTagName, IgcToolActionRadioComponent);
            }
        }
        /**
         * Gets or sets the channel this radio button belongs to.
        */
        get channel() {
            return this.i.hk;
        }
        set channel(v) {
            this.i.hk = v;
        }
        /**
         * Gets or sets if the tool action is checked.
        */
        get isChecked() {
            return this.i.hd;
        }
        set isChecked(v) {
            this.i.hd = ensureBool(v);
            this._a("isChecked", this.i.hd);
        }
        /**
         * Gets or sets if the checked state of the radio is handled manually by the user. The radio
         * well not become selected when clicked if this property is true.
        */
        get isManual() {
            return this.i.he;
        }
        set isManual(v) {
            this.i.he = ensureBool(v);
            this._a("isManual", this.i.he);
        }
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get uncheckedBackgroundColor() {
            return brushToString(this.i.h8);
        }
        set uncheckedBackgroundColor(v) {
            this.i.h8 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.h8));
        }
        /**
         * Gets the actual background color of the radio when in the unchecked state.
        */
        get actualUncheckedBackgroundColor() {
            return brushToString(this.i.h4);
        }
        set actualUncheckedBackgroundColor(v) {
            this.i.h4 = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.h4));
        }
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get checkedBackgroundColor() {
            return brushToString(this.i.h6);
        }
        set checkedBackgroundColor(v) {
            this.i.h6 = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.h6));
        }
        /**
         * Gets the actual background color of the radio when in the checked state.
        */
        get actualCheckedBackgroundColor() {
            return brushToString(this.i.h2);
        }
        set actualCheckedBackgroundColor(v) {
            this.i.h2 = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.h2));
        }
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get uncheckedBorderColor() {
            return brushToString(this.i.h9);
        }
        set uncheckedBorderColor(v) {
            this.i.h9 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.h9));
        }
        /**
         * Gets the actual border color of the radio when in the unchecked state.
        */
        get actualUncheckedBorderColor() {
            return brushToString(this.i.h5);
        }
        set actualUncheckedBorderColor(v) {
            this.i.h5 = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.h5));
        }
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get checkedBorderColor() {
            return brushToString(this.i.h7);
        }
        set checkedBorderColor(v) {
            this.i.h7 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.h7));
        }
        /**
         * Gets the actual border color of the radio when in the checked state.
        */
        get actualCheckedBorderColor() {
            return brushToString(this.i.h3);
        }
        set actualCheckedBorderColor(v) {
            this.i.h3 = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.h3));
        }
    }
    IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = null;
    IgcToolActionRadioComponent.htmlTagName = "igc-tool-action-radio";
    IgcToolActionRadioComponent._isElementRegistered = false;
    return IgcToolActionRadioComponent;
})();
